pub struct Display<'s> { /* private fields */ }Expand description
A collection of format strings that are evaluated to a string-to-string mapping.
Implementations
Sourceimpl<'s> Display<'s>
impl<'s> Display<'s>
Sourcepub fn parse(
limits: Limits,
display_fields: impl IntoIterator<Item = (&'s str, &'s str)>,
) -> Result<Self, Error>
pub fn parse( limits: Limits, display_fields: impl IntoIterator<Item = (&'s str, &'s str)>, ) -> Result<Self, Error>
Convert the contents of a Display object into a Format by parsing each of its names and
values as format strings.
limits bound the dimensions (depth, number of output nodes, max number of object loads)
that the parsed format can consume.
This operation supports partial failures (if one of the format strings is invalid), but
will fail completely if the display overall is detected to exceed the provided limits.
Sourcepub async fn display<V: Format>(
&'s self,
max_depth: usize,
max_output_size: usize,
interpreter: &'s Interpreter<impl Store>,
) -> Result<IndexMap<String, Result<V, FormatError>>, Error>
pub async fn display<V: Format>( &'s self, max_depth: usize, max_output_size: usize, interpreter: &'s Interpreter<impl Store>, ) -> Result<IndexMap<String, Result<V, FormatError>>, Error>
Render the format with the provided interpreter
This operation requires all field names to evaluate successfully to unique strings, and for
the overall output to be bounded by max_depth and max_output_size, but otherwise
supports partial failures (if one of the field values fails to parse or evaluate).